==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/GetTransactionJson.java <==
package com.example.model;

/**
 * Model for Get Transaction as JSON
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "GetTransactionJson", description = "Model for Get Transaction as JSON")
@javax.xml.bind.annotation.XmlRootElement(name = "GetTransactionJson")
public class GetTransactionJson implements java.io.Serializable, com.example.model.Get200Response {

	private static final long serialVersionUID = 1L;
	private java.time.OffsetDateTime createdAt = null;
	private java.lang.String currentStep = null;
	private com.example.model.DataProviderData dataProvider = null;
	private com.example.model.DeviceInfo deviceInfo = null;
	private java.util.List<com.example.model.Documents> documents = null;
	private com.example.model.File facematchBestFrame = null;
	private java.lang.String flowType = null;
	private com.example.model.LikenessFeatures likenessFeatures = null;
	private java.lang.String likenessOverall = null;
	private java.util.List<com.example.model.LivenessAttempts> livenessAttempts = null;
	private com.example.model.Results results = null;
	private java.lang.String spoofResult = null;
	private java.lang.String status = null;
	private java.lang.String transactionId = null;
	private com.example.model.UserDetails userDetails = null;
	
	/**
	 */
	public GetTransactionJson createdAt(java.time.OffsetDateTime createdAt) {
		setCreatedAt(createdAt);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("created_at")
	@javax.validation.constraints.NotNull
	public java.time.OffsetDateTime getCreatedAt() {
		return this.createdAt;
	}
	public void setCreatedAt(java.time.OffsetDateTime createdAt) {
		this.createdAt = createdAt;
	}
	
	/**
	 */
	public GetTransactionJson currentStep(java.lang.String currentStep) {
		setCurrentStep(currentStep);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("current_step")
	public java.lang.String getCurrentStep() {
		return this.currentStep;
	}
	public void setCurrentStep(java.lang.String currentStep) {
		this.currentStep = currentStep;
	}
	
	/**
	 * Model for DataProvider
	 */
	public GetTransactionJson dataProvider(com.example.model.DataProviderData dataProvider) {
		setDataProvider(dataProvider);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for DataProvider")
	@com.fasterxml.jackson.annotation.JsonProperty("data_provider")
	@javax.validation.Valid
	public com.example.model.DataProviderData getDataProvider() {
		return this.dataProvider;
	}
	public void setDataProvider(com.example.model.DataProviderData dataProvider) {
		this.dataProvider = dataProvider;
	}
	
	/**
	 * Model for DeviceInfo
	 */
	public GetTransactionJson deviceInfo(com.example.model.DeviceInfo deviceInfo) {
		setDeviceInfo(deviceInfo);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for DeviceInfo")
	@com.fasterxml.jackson.annotation.JsonProperty("device_info")
	@javax.validation.Valid
	public com.example.model.DeviceInfo getDeviceInfo() {
		return this.deviceInfo;
	}
	public void setDeviceInfo(com.example.model.DeviceInfo deviceInfo) {
		this.deviceInfo = deviceInfo;
	}
	
	/**
	 */
	public GetTransactionJson documents(java.util.List<com.example.model.Documents> documents) {
		setDocuments(documents);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("documents")
	@javax.validation.Valid
	public java.util.List<com.example.model.Documents> getDocuments() {
		return this.documents;
	}
	public void setDocuments(java.util.List<com.example.model.Documents> documents) {
		this.documents = documents;
	}
	public GetTransactionJson addDocument(com.example.model.Documents document) {
		if (this.documents == null) {
			this.documents = new java.util.ArrayList<com.example.model.Documents>();
		}
		this.documents.add(document);
		return this;
	}
	
	/**
	 * Model for File
	 */
	public GetTransactionJson facematchBestFrame(com.example.model.File facematchBestFrame) {
		setFacematchBestFrame(facematchBestFrame);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for File")
	@com.fasterxml.jackson.annotation.JsonProperty("facematch_best_frame")
	@javax.validation.Valid
	public com.example.model.File getFacematchBestFrame() {
		return this.facematchBestFrame;
	}
	public void setFacematchBestFrame(com.example.model.File facematchBestFrame) {
		this.facematchBestFrame = facematchBestFrame;
	}
	
	/**
	 */
	public GetTransactionJson flowType(java.lang.String flowType) {
		setFlowType(flowType);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("flow_type")
	public java.lang.String getFlowType() {
		return this.flowType;
	}
	public void setFlowType(java.lang.String flowType) {
		this.flowType = flowType;
	}
	
	/**
	 * Model for LikenessFeatures
	 */
	public GetTransactionJson likenessFeatures(com.example.model.LikenessFeatures likenessFeatures) {
		setLikenessFeatures(likenessFeatures);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for LikenessFeatures")
	@com.fasterxml.jackson.annotation.JsonProperty("likeness_features")
	@javax.validation.Valid
	public com.example.model.LikenessFeatures getLikenessFeatures() {
		return this.likenessFeatures;
	}
	public void setLikenessFeatures(com.example.model.LikenessFeatures likenessFeatures) {
		this.likenessFeatures = likenessFeatures;
	}
	
	/**
	 */
	public GetTransactionJson likenessOverall(java.lang.String likenessOverall) {
		setLikenessOverall(likenessOverall);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("likeness_overall")
	public java.lang.String getLikenessOverall() {
		return this.likenessOverall;
	}
	public void setLikenessOverall(java.lang.String likenessOverall) {
		this.likenessOverall = likenessOverall;
	}
	
	/**
	 */
	public GetTransactionJson livenessAttempts(java.util.List<com.example.model.LivenessAttempts> livenessAttempts) {
		setLivenessAttempts(livenessAttempts);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("liveness_attempts")
	@javax.validation.Valid
	public java.util.List<com.example.model.LivenessAttempts> getLivenessAttempts() {
		return this.livenessAttempts;
	}
	public void setLivenessAttempts(java.util.List<com.example.model.LivenessAttempts> livenessAttempts) {
		this.livenessAttempts = livenessAttempts;
	}
	public GetTransactionJson addLivenessAttempt(com.example.model.LivenessAttempts livenessAttempt) {
		if (this.livenessAttempts == null) {
			this.livenessAttempts = new java.util.ArrayList<com.example.model.LivenessAttempts>();
		}
		this.livenessAttempts.add(livenessAttempt);
		return this;
	}
	
	/**
	 * Model for Results
	 */
	public GetTransactionJson results(com.example.model.Results results) {
		setResults(results);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for Results")
	@com.fasterxml.jackson.annotation.JsonProperty("results")
	@javax.validation.Valid
	public com.example.model.Results getResults() {
		return this.results;
	}
	public void setResults(com.example.model.Results results) {
		this.results = results;
	}
	
	/**
	 */
	public GetTransactionJson spoofResult(java.lang.String spoofResult) {
		setSpoofResult(spoofResult);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("spoof_result")
	public java.lang.String getSpoofResult() {
		return this.spoofResult;
	}
	public void setSpoofResult(java.lang.String spoofResult) {
		this.spoofResult = spoofResult;
	}
	
	/**
	 */
	public GetTransactionJson status(java.lang.String status) {
		setStatus(status);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("status")
	public java.lang.String getStatus() {
		return this.status;
	}
	public void setStatus(java.lang.String status) {
		this.status = status;
	}
	
	/**
	 */
	public GetTransactionJson transactionId(java.lang.String transactionId) {
		setTransactionId(transactionId);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("transaction_id")
	public java.lang.String getTransactionId() {
		return this.transactionId;
	}
	public void setTransactionId(java.lang.String transactionId) {
		this.transactionId = transactionId;
	}
	
	/**
	 * Model for UserDetails
	 */
	public GetTransactionJson userDetails(com.example.model.UserDetails userDetails) {
		setUserDetails(userDetails);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for UserDetails")
	@com.fasterxml.jackson.annotation.JsonProperty("user_details")
	@javax.validation.Valid
	public com.example.model.UserDetails getUserDetails() {
		return this.userDetails;
	}
	public void setUserDetails(com.example.model.UserDetails userDetails) {
		this.userDetails = userDetails;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		GetTransactionJson getTransactionJson = (GetTransactionJson) o;
		return java.util.Objects.equals(this.createdAt, getTransactionJson.createdAt)
				&& java.util.Objects.equals(this.currentStep, getTransactionJson.currentStep)
				&& java.util.Objects.equals(this.dataProvider, getTransactionJson.dataProvider)
				&& java.util.Objects.equals(this.deviceInfo, getTransactionJson.deviceInfo)
				&& java.util.Objects.equals(this.documents, getTransactionJson.documents)
				&& java.util.Objects.equals(this.facematchBestFrame, getTransactionJson.facematchBestFrame)
				&& java.util.Objects.equals(this.flowType, getTransactionJson.flowType)
				&& java.util.Objects.equals(this.likenessFeatures, getTransactionJson.likenessFeatures)
				&& java.util.Objects.equals(this.likenessOverall, getTransactionJson.likenessOverall)
				&& java.util.Objects.equals(this.livenessAttempts, getTransactionJson.livenessAttempts)
				&& java.util.Objects.equals(this.results, getTransactionJson.results)
				&& java.util.Objects.equals(this.spoofResult, getTransactionJson.spoofResult)
				&& java.util.Objects.equals(this.status, getTransactionJson.status)
				&& java.util.Objects.equals(this.transactionId, getTransactionJson.transactionId)
				&& java.util.Objects.equals(this.userDetails, getTransactionJson.userDetails);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.createdAt, this.currentStep, this.dataProvider, this.deviceInfo, this.documents, this.facematchBestFrame, this.flowType, this.likenessFeatures, this.likenessOverall, this.livenessAttempts, this.results, this.spoofResult, this.status, this.transactionId, this.userDetails);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class GetTransactionJson {\n");
		
		sb.append("    createdAt: ").append(toIndentedString(this.createdAt)).append("\n");
		sb.append("    currentStep: ").append(toIndentedString(this.currentStep)).append("\n");
		sb.append("    dataProvider: ").append(toIndentedString(this.dataProvider)).append("\n");
		sb.append("    deviceInfo: ").append(toIndentedString(this.deviceInfo)).append("\n");
		sb.append("    documents: ").append(toIndentedString(this.documents)).append("\n");
		sb.append("    facematchBestFrame: ").append(toIndentedString(this.facematchBestFrame)).append("\n");
		sb.append("    flowType: ").append(toIndentedString(this.flowType)).append("\n");
		sb.append("    likenessFeatures: ").append(toIndentedString(this.likenessFeatures)).append("\n");
		sb.append("    likenessOverall: ").append(toIndentedString(this.likenessOverall)).append("\n");
		sb.append("    livenessAttempts: ").append(toIndentedString(this.livenessAttempts)).append("\n");
		sb.append("    results: ").append(toIndentedString(this.results)).append("\n");
		sb.append("    spoofResult: ").append(toIndentedString(this.spoofResult)).append("\n");
		sb.append("    status: ").append(toIndentedString(this.status)).append("\n");
		sb.append("    transactionId: ").append(toIndentedString(this.transactionId)).append("\n");
		sb.append("    userDetails: ").append(toIndentedString(this.userDetails)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/GetTransactionJson.java <==
package com.example.model;

/**
 * Model for Get Transaction as JSON
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "GetTransactionJson", description = "Model for Get Transaction as JSON")
@javax.xml.bind.annotation.XmlRootElement(name = "GetTransactionJson")
public class GetTransactionJson implements java.io.Serializable, com.example.model.Get200Response {

	private static final long serialVersionUID = 1L;
	private java.time.OffsetDateTime createdAt = null;
	private java.lang.String currentStep = null;
	private com.example.model.DataProviderData dataProvider = null;
	private com.example.model.DeviceInfo deviceInfo = null;
	private java.util.List<com.example.model.Documents> documents = null;
	private com.example.model.File facematchBestFrame = null;
	private java.lang.String flowType = null;
	private com.example.model.LikenessFeatures likenessFeatures = null;
	private java.lang.String likenessOverall = null;
	private java.util.List<com.example.model.LivenessAttempts> livenessAttempts = null;
	private com.example.model.Results results = null;
	private java.lang.String spoofResult = null;
	private java.lang.String status = null;
	private java.lang.String transactionId = null;
	private com.example.model.UserDetails userDetails = null;
	
	/**
	 */
	public GetTransactionJson createdAt(java.time.OffsetDateTime createdAt) {
		setCreatedAt(createdAt);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "created_at")
	@com.fasterxml.jackson.annotation.JsonProperty("created_at")
	@javax.validation.constraints.NotNull
	public java.time.OffsetDateTime getCreatedAt() {
		return this.createdAt;
	}
	public void setCreatedAt(java.time.OffsetDateTime createdAt) {
		this.createdAt = createdAt;
	}
	
	/**
	 */
	public GetTransactionJson currentStep(java.lang.String currentStep) {
		setCurrentStep(currentStep);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "current_step")
	@com.fasterxml.jackson.annotation.JsonProperty("current_step")
	public java.lang.String getCurrentStep() {
		return this.currentStep;
	}
	public void setCurrentStep(java.lang.String currentStep) {
		this.currentStep = currentStep;
	}
	
	/**
	 * Model for DataProvider
	 */
	public GetTransactionJson dataProvider(com.example.model.DataProviderData dataProvider) {
		setDataProvider(dataProvider);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "data_provider", description = "Model for DataProvider")
	@com.fasterxml.jackson.annotation.JsonProperty("data_provider")
	@javax.validation.Valid
	public com.example.model.DataProviderData getDataProvider() {
		return this.dataProvider;
	}
	public void setDataProvider(com.example.model.DataProviderData dataProvider) {
		this.dataProvider = dataProvider;
	}
	
	/**
	 * Model for DeviceInfo
	 */
	public GetTransactionJson deviceInfo(com.example.model.DeviceInfo deviceInfo) {
		setDeviceInfo(deviceInfo);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "device_info", description = "Model for DeviceInfo")
	@com.fasterxml.jackson.annotation.JsonProperty("device_info")
	@javax.validation.Valid
	public com.example.model.DeviceInfo getDeviceInfo() {
		return this.deviceInfo;
	}
	public void setDeviceInfo(com.example.model.DeviceInfo deviceInfo) {
		this.deviceInfo = deviceInfo;
	}
	
	/**
	 */
	public GetTransactionJson documents(java.util.List<com.example.model.Documents> documents) {
		setDocuments(documents);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "documents")
	@com.fasterxml.jackson.annotation.JsonProperty("documents")
	@javax.validation.Valid
	public java.util.List<com.example.model.Documents> getDocuments() {
		return this.documents;
	}
	public void setDocuments(java.util.List<com.example.model.Documents> documents) {
		this.documents = documents;
	}
	public GetTransactionJson addDocument(com.example.model.Documents document) {
		if (this.documents == null) {
			this.documents = new java.util.ArrayList<com.example.model.Documents>();
		}
		this.documents.add(document);
		return this;
	}
	
	/**
	 * Model for File
	 */
	public GetTransactionJson facematchBestFrame(com.example.model.File facematchBestFrame) {
		setFacematchBestFrame(facematchBestFrame);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "facematch_best_frame", description = "Model for File")
	@com.fasterxml.jackson.annotation.JsonProperty("facematch_best_frame")
	@javax.validation.Valid
	public com.example.model.File getFacematchBestFrame() {
		return this.facematchBestFrame;
	}
	public void setFacematchBestFrame(com.example.model.File facematchBestFrame) {
		this.facematchBestFrame = facematchBestFrame;
	}
	
	/**
	 */
	public GetTransactionJson flowType(java.lang.String flowType) {
		setFlowType(flowType);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "flow_type")
	@com.fasterxml.jackson.annotation.JsonProperty("flow_type")
	public java.lang.String getFlowType() {
		return this.flowType;
	}
	public void setFlowType(java.lang.String flowType) {
		this.flowType = flowType;
	}
	
	/**
	 * Model for LikenessFeatures
	 */
	public GetTransactionJson likenessFeatures(com.example.model.LikenessFeatures likenessFeatures) {
		setLikenessFeatures(likenessFeatures);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "likeness_features", description = "Model for LikenessFeatures")
	@com.fasterxml.jackson.annotation.JsonProperty("likeness_features")
	@javax.validation.Valid
	public com.example.model.LikenessFeatures getLikenessFeatures() {
		return this.likenessFeatures;
	}
	public void setLikenessFeatures(com.example.model.LikenessFeatures likenessFeatures) {
		this.likenessFeatures = likenessFeatures;
	}
	
	/**
	 */
	public GetTransactionJson likenessOverall(java.lang.String likenessOverall) {
		setLikenessOverall(likenessOverall);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "likeness_overall")
	@com.fasterxml.jackson.annotation.JsonProperty("likeness_overall")
	public java.lang.String getLikenessOverall() {
		return this.likenessOverall;
	}
	public void setLikenessOverall(java.lang.String likenessOverall) {
		this.likenessOverall = likenessOverall;
	}
	
	/**
	 */
	public GetTransactionJson livenessAttempts(java.util.List<com.example.model.LivenessAttempts> livenessAttempts) {
		setLivenessAttempts(livenessAttempts);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "liveness_attempts")
	@com.fasterxml.jackson.annotation.JsonProperty("liveness_attempts")
	@javax.validation.Valid
	public java.util.List<com.example.model.LivenessAttempts> getLivenessAttempts() {
		return this.livenessAttempts;
	}
	public void setLivenessAttempts(java.util.List<com.example.model.LivenessAttempts> livenessAttempts) {
		this.livenessAttempts = livenessAttempts;
	}
	public GetTransactionJson addLivenessAttempt(com.example.model.LivenessAttempts livenessAttempt) {
		if (this.livenessAttempts == null) {
			this.livenessAttempts = new java.util.ArrayList<com.example.model.LivenessAttempts>();
		}
		this.livenessAttempts.add(livenessAttempt);
		return this;
	}
	
	/**
	 * Model for Results
	 */
	public GetTransactionJson results(com.example.model.Results results) {
		setResults(results);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "results", description = "Model for Results")
	@com.fasterxml.jackson.annotation.JsonProperty("results")
	@javax.validation.Valid
	public com.example.model.Results getResults() {
		return this.results;
	}
	public void setResults(com.example.model.Results results) {
		this.results = results;
	}
	
	/**
	 */
	public GetTransactionJson spoofResult(java.lang.String spoofResult) {
		setSpoofResult(spoofResult);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "spoof_result")
	@com.fasterxml.jackson.annotation.JsonProperty("spoof_result")
	public java.lang.String getSpoofResult() {
		return this.spoofResult;
	}
	public void setSpoofResult(java.lang.String spoofResult) {
		this.spoofResult = spoofResult;
	}
	
	/**
	 */
	public GetTransactionJson status(java.lang.String status) {
		setStatus(status);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "status")
	@com.fasterxml.jackson.annotation.JsonProperty("status")
	public java.lang.String getStatus() {
		return this.status;
	}
	public void setStatus(java.lang.String status) {
		this.status = status;
	}
	
	/**
	 */
	public GetTransactionJson transactionId(java.lang.String transactionId) {
		setTransactionId(transactionId);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "transaction_id")
	@com.fasterxml.jackson.annotation.JsonProperty("transaction_id")
	public java.lang.String getTransactionId() {
		return this.transactionId;
	}
	public void setTransactionId(java.lang.String transactionId) {
		this.transactionId = transactionId;
	}
	
	/**
	 * Model for UserDetails
	 */
	public GetTransactionJson userDetails(com.example.model.UserDetails userDetails) {
		setUserDetails(userDetails);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "user_details", description = "Model for UserDetails")
	@com.fasterxml.jackson.annotation.JsonProperty("user_details")
	@javax.validation.Valid
	public com.example.model.UserDetails getUserDetails() {
		return this.userDetails;
	}
	public void setUserDetails(com.example.model.UserDetails userDetails) {
		this.userDetails = userDetails;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		GetTransactionJson getTransactionJson = (GetTransactionJson) o;
		return java.util.Objects.equals(this.createdAt, getTransactionJson.createdAt)
				&& java.util.Objects.equals(this.currentStep, getTransactionJson.currentStep)
				&& java.util.Objects.equals(this.dataProvider, getTransactionJson.dataProvider)
				&& java.util.Objects.equals(this.deviceInfo, getTransactionJson.deviceInfo)
				&& java.util.Objects.equals(this.documents, getTransactionJson.documents)
				&& java.util.Objects.equals(this.facematchBestFrame, getTransactionJson.facematchBestFrame)
				&& java.util.Objects.equals(this.flowType, getTransactionJson.flowType)
				&& java.util.Objects.equals(this.likenessFeatures, getTransactionJson.likenessFeatures)
				&& java.util.Objects.equals(this.likenessOverall, getTransactionJson.likenessOverall)
				&& java.util.Objects.equals(this.livenessAttempts, getTransactionJson.livenessAttempts)
				&& java.util.Objects.equals(this.results, getTransactionJson.results)
				&& java.util.Objects.equals(this.spoofResult, getTransactionJson.spoofResult)
				&& java.util.Objects.equals(this.status, getTransactionJson.status)
				&& java.util.Objects.equals(this.transactionId, getTransactionJson.transactionId)
				&& java.util.Objects.equals(this.userDetails, getTransactionJson.userDetails);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.createdAt, this.currentStep, this.dataProvider, this.deviceInfo, this.documents, this.facematchBestFrame, this.flowType, this.likenessFeatures, this.likenessOverall, this.livenessAttempts, this.results, this.spoofResult, this.status, this.transactionId, this.userDetails);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class GetTransactionJson {\n");
		
		sb.append("    createdAt: ").append(toIndentedString(this.createdAt)).append("\n");
		sb.append("    currentStep: ").append(toIndentedString(this.currentStep)).append("\n");
		sb.append("    dataProvider: ").append(toIndentedString(this.dataProvider)).append("\n");
		sb.append("    deviceInfo: ").append(toIndentedString(this.deviceInfo)).append("\n");
		sb.append("    documents: ").append(toIndentedString(this.documents)).append("\n");
		sb.append("    facematchBestFrame: ").append(toIndentedString(this.facematchBestFrame)).append("\n");
		sb.append("    flowType: ").append(toIndentedString(this.flowType)).append("\n");
		sb.append("    likenessFeatures: ").append(toIndentedString(this.likenessFeatures)).append("\n");
		sb.append("    likenessOverall: ").append(toIndentedString(this.likenessOverall)).append("\n");
		sb.append("    livenessAttempts: ").append(toIndentedString(this.livenessAttempts)).append("\n");
		sb.append("    results: ").append(toIndentedString(this.results)).append("\n");
		sb.append("    spoofResult: ").append(toIndentedString(this.spoofResult)).append("\n");
		sb.append("    status: ").append(toIndentedString(this.status)).append("\n");
		sb.append("    transactionId: ").append(toIndentedString(this.transactionId)).append("\n");
		sb.append("    userDetails: ").append(toIndentedString(this.userDetails)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
